@@ -3,13 +3,15 @@
 #'
 #' Rev code can be ran directly in knitr chunks, without the use of the functions doRev() or repRev(). History is accessed with the .Revhistory file and persists between chunks.
 #'
+#'
 #' @return No return. Initiates knitr engine for RevBayes.
 #'
 #'@export
 knitRev <- function(){
+
   knitr::knit_engines$set(rb = function(options) {
 
-    output <- doRev(options$code)
+    output <- doRev(paste(options$code, collapse = "\n"))
 
     return(knitr::engine_output(options, code = options$code, out = c(output)))
   })
